# eric7.Plugins.WizardPlugins.InputDialogWizard.InputDialogWizardDialog

Module implementing the input dialog wizard dialog.

### Global Attributes

None

### Classes

InputDialogWizardDialog | Class implementing the input dialog wizard dialog.

### Functions

None

## InputDialogWizardDialog

Class implementing the input dialog wizard dialog.

It displays a dialog for entering the parameters for the QInputDialog code generator.

### Derived from

QDialog, Ui_InputDialogWizardDialog

### Class Attributes

None

### Class Methods

None

### Methods

InputDialogWizardDialog | Constructor
__typeSelectButtonToggled | Private slot to modify the dialog according to the selected type.
getCode | Public method to get the source code for Qt6.
on_bTest_clicked | Private method to test the selected options.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.

### Static Methods

None

#### InputDialogWizardDialog (Constructor)

InputDialogWizardDialog(parent=None)

Constructor

parent
  parent widget (QWidget)

#### InputDialogWizardDialog.__typeSelectButtonToggled

__typeSelectButtonToggled(checked)

Private slot to modify the dialog according to the selected type.

Note: This is a multiplexed slot. Therefore it just reacts upon a positive check state (i.e. checked == True).

checked (bool)
  flag indicating the checked state

#### InputDialogWizardDialog.getCode

getCode(indLevel, indString)

Public method to get the source code for Qt6.

indLevel
  indentation level (int)
indString
  string used for indentation (space or tab) (string)

Return:
  generated code (string)

#### InputDialogWizardDialog.on_bTest_clicked

on_bTest_clicked()

Private method to test the selected options.

#### InputDialogWizardDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button
  button that was clicked (QAbstractButton)

Up